[Schmitzm-commits] r1729 - trunk/schmitzm-core/src/main/java/de/schmitzm/postgres

scm-commit@wald.intevation.org scm-commit at wald.intevation.org
Sat Sep 24 16:14:33 CEST 2011


Author: alfonx
Date: 2011-09-24 16:14:32 +0200 (Sat, 24 Sep 2011)
New Revision: 1729

Modified:
   trunk/schmitzm-core/src/main/java/de/schmitzm/postgres/PGUtil.java
Log:
	/**
	 * Liefert die Anzahl der offenen Sessions zur Datenbank.
	 * 
	 * @param c
	 *            DB-Verbindung
	 * @param dbName
	 *            Name der Datenbank fuer die die Sessions gezaehlt werden (kann {@code null} sein)
	 * @param userName
	 *            Name des Users fuer den die Sessions gezaehlt werden (kann {@code null} sein)
	 * @param queryLike
	 *            like-Beindung auf die Query die in der Session ausgef?\195?\188hrt wird, oder <code>null</code>
	 */
	public static int getOpenSessionCount(Connection c, String dbName, String userName, String queryLike)
			throws SQLException {

Modified: trunk/schmitzm-core/src/main/java/de/schmitzm/postgres/PGUtil.java
===================================================================
--- trunk/schmitzm-core/src/main/java/de/schmitzm/postgres/PGUtil.java	2011-09-13 15:33:33 UTC (rev 1728)
+++ trunk/schmitzm-core/src/main/java/de/schmitzm/postgres/PGUtil.java	2011-09-24 14:14:32 UTC (rev 1729)
@@ -13,15 +13,14 @@
 import de.schmitzm.lang.LangUtil;
 
 /**
  * Hilfsmethoden für PostgreSQL. Die Dependency soll nur {@link Connection}
  * sein. In Hibernate kann über #doWork eine {@link Connection} erhalten werden.
  */
 public class PGUtil {
 	static final Logger log = Logger.getLogger(PGUtil.class);
 
 	/**
-	 * PostgreSQL Privilegien die per Grant einer Tabelle zugeordnet werden
-	 * können.<br/>
+	 * PostgreSQL Privilegien die per Grant einer Tabelle zugeordnet werden können.<br/>
 	 * 
 	 * @see http://www.postgresql.org/docs/9.1/static/sql-grant.html
 	 */
@@ -89,8 +88,8 @@
 	}
 
 	/**
-	 * Querys the <code>geometry_columns</code> table is part of every POSTGIS
-	 * installation and must/should describe the geometry columns and tables.
+	 * Querys the <code>geometry_columns</code> table is part of every POSTGIS installation and must/should describe the
+	 * geometry columns and tables.
 	 */
 	static public String[] getColumnsDescribedInGeometryColumnsTable(Statement s) {
 		String[] columns = new String[0];
@@ -132,8 +131,8 @@
 	/**
 	 * @param binding
 	 *            Eine "einfache" Javaklasse, die in PG abgebildet werden soll.
-	 * @return einen PG-spezifischen Datentypenamen für einen Javatyp zurück,
-	 *         z.b. "double precision" für <code>Double.class</code>
+	 * @return einen PG-spezifischen Datentypenamen für einen Javatyp zurück, z.b. "double precision" für
+	 *         <code>Double.class</code>
 	 */
 	public static String getColTypeName(Class<?> binding) {
 
@@ -164,8 +163,7 @@
 	}
 
 	/**
-	 * Liefert <code>true</code> wenn ein Schema mit dem Namen in der PG
-	 * Datenbank existiert.
+	 * Liefert <code>true</code> wenn ein Schema mit dem Namen in der PG Datenbank existiert.
 	 */
 	public static boolean existsSchema(Connection c, String schemaname) throws SQLException {
 		String sql = "select 1 from pg_catalog.pg_namespace where nspname = '" + schemaname.toLowerCase() + "'";
@@ -179,8 +177,7 @@
 	}
 
 	/**
-	 * Liefert eine Liste der Rollen in denen der Übergebenen USER (Login role)
-	 * ist. <br/>
+	 * Liefert eine Liste der Rollen in denen der Übergebenen USER (Login role) ist. <br/>
 	 * Tested with PG 8.4
 	 */
 	public static List<String> listRolesForUser(Connection c, String username) throws SQLException {
@@ -217,8 +214,8 @@
 	}
 
 	/**
-	 * Liste aller Tabellennamen in diesem Schema, ohne die Schemaangabe im
-	 * Namen. (Also 'anreden' und nicht 'public.anreden') <br/>
+	 * Liste aller Tabellennamen in diesem Schema, ohne die Schemaangabe im Namen. (Also 'anreden' und nicht
+	 * 'public.anreden') <br/>
 	 * Tested with PG 8.4
 	 * 
 	 * @param schemaname
@@ -296,9 +293,7 @@
 	 * @param name
 	 *            z.B.: keckformel wird dann zu keckformel()
 	 * @param plCommands
-	 *            z.B. NEW.kpk_kreis =
-	 *            NEW.risiko_soz+NEW.risiko_emo+NEW.risiko_moti
-	 *            +NEW.risiko_spr+NEW.risiko_wohl;
+	 *            z.B. NEW.kpk_kreis = NEW.risiko_soz+NEW.risiko_emo+NEW.risiko_moti +NEW.risiko_spr+NEW.risiko_wohl;
 	 * @throws SQLException
 	 */
 	public static void createOrReplaceFunction(Connection c, String name, String plCommands) throws SQLException {
@@ -334,8 +329,7 @@
 	 * @param idxNamePostfix
 	 *            e.g. 'idx1'
 	 * @param unique
-	 *            <code>true</code> if the columns are unique. A UNIQUE INDEX
-	 *            will be created.
+	 *            <code>true</code> if the columns are unique. A UNIQUE INDEX will be created.
 	 */
 	public static void addIndex(Connection c, final String tableName, final String columns, String idxPostfix,
 			final boolean unique) throws SQLException {
@@ -343,11 +337,10 @@
 	}
 
 	/**
-	 * Liefert eine Liste aller Indexnamen die für eine Tabelle existieren. Der
-	 * Tabellenname wird mit <code>like</code> verglichen, darf also
-	 * <code>%</code> enthalten.<br/>
-	 * Achtung: Diese abfrage ist nicht Schema-Spezifisch. Eine schema. Angabe
-	 * vor dem tabellennamen wird automatisch entfernt.
+	 * Liefert eine Liste aller Indexnamen die für eine Tabelle existieren. Der Tabellenname wird mit <code>like</code>
+	 * verglichen, darf also <code>%</code> enthalten.<br/>
+	 * Achtung: Diese abfrage ist nicht Schema-Spezifisch. Eine schema. Angabe vor dem tabellennamen wird automatisch
+	 * entfernt.
 	 */
 	public static List<String> listIndexesForTable(Connection c, String tableName) throws SQLException {
 		Statement s = c.createStatement();
@@ -381,11 +374,9 @@
 	 * @param idxNamePostfix
 	 *            e.g. 'idx1'
 	 * @param unique
-	 *            <code>true</code> if the columns are unique. A UNIQUE INDEX
-	 *            will be created.
+	 *            <code>true</code> if the columns are unique. A UNIQUE INDEX will be created.
 	 * @param tablespace
-	 *            <code>null</code> oder der name des tablespace in dem der
-	 *            Index liegen soll.
+	 *            <code>null</code> oder der name des tablespace in dem der Index liegen soll.
 	 */
 	public static void addIndex(Connection c, final String tableName, final String columns, String idxPostfix,
 			final boolean unique, String tablespace) throws SQLException {
@@ -430,8 +421,8 @@
 	}
 
 	/**
-	 * Fügt einen Benutzer zu einer Rolle hinzu. Wenn der benutzer bereits in
-	 * der Rolle enthalten ist, wird keine Exception geschmisssen.
+	 * Fügt einen Benutzer zu einer Rolle hinzu. Wenn der benutzer bereits in der Rolle enthalten ist, wird keine
+	 * Exception geschmisssen.
 	 * 
 	 * @throws SQLException
 	 */
@@ -440,9 +431,8 @@
 	}
 
 	/**
-	 * Der : (Doppelpunkt) hat in PSQL eine besondere Bedeutung. Er wind mit
-	 * dieser methode escaped. Diese Methode sollte mit
-	 * <code>like E'"+PGUtil.escape(...)+"'</code> verwendet werden.
+	 * Der : (Doppelpunkt) hat in PSQL eine besondere Bedeutung. Er wind mit dieser methode escaped. Diese Methode
+	 * sollte mit <code>like E'"+PGUtil.escape(...)+"'</code> verwendet werden.
 	 */
 	public static String escape(String key) {
 		key = key.replaceAll(":", "\\:");
@@ -455,19 +445,37 @@
 	 * @param c
 	 *            DB-Verbindung
 	 * @param dbName
-	 *            Name der Datenbank fuer die die Sessions gezaehlt werden (kann
-	 *            {@code null} sein)
+	 *            Name der Datenbank fuer die die Sessions gezaehlt werden (kann {@code null} sein)
 	 * @param userName
-	 *            Name des Users fuer den die Sessions gezaehlt werden (kann
-	 *            {@code null} sein)
+	 *            Name des Users fuer den die Sessions gezaehlt werden (kann {@code null} sein)
 	 */
 	public static int getOpenSessionCount(Connection c, String dbName, String userName) throws SQLException {
+		return getOpenSessionCount(c, dbName, userName, null);
+	}
+	
+	/**
+	 * Liefert die Anzahl der offenen Sessions zur Datenbank.
+	 * 
+	 * @param c
+	 *            DB-Verbindung
+	 * @param dbName
+	 *            Name der Datenbank fuer die die Sessions gezaehlt werden (kann {@code null} sein)
+	 * @param userName
+	 *            Name des Users fuer den die Sessions gezaehlt werden (kann {@code null} sein)
+	 * @param queryLike
+	 *            like-Beindung auf die Query die in der Session ausgeführt wird, oder <code>null</code>
+	 */
+	public static int getOpenSessionCount(Connection c, String dbName, String userName, String queryLike)
+			throws SQLException {
 		String stmtSql = "SELECT COUNT(*) FROM pg_stat_activity WHERE TRUE";
 
 		if (dbName != null)
 			stmtSql += " AND datname = ?";
 		if (userName != null)
 			stmtSql += " AND usename = ?";
+		if (queryLike != null) {
+			stmtSql += " AND current_query like '" + queryLike + "'";
+		}
 
 		PreparedStatement stmt = c.prepareStatement(stmtSql);
 		if (dbName != null)
@@ -13,15 +13,14 @@
 
 /**
- * Hilfsmethoden für PostgreSQL. Die Dependency soll nur {@link Connection}
- * sein. In Hibernate kann über #doWork eine {@link Connection} erhalten werden.
+ * Hilfsmethoden für PostgreSQL. Die Dependency soll nur {@link Connection} sein. In Hibernate kann über #doWork eine
+ * {@link Connection} erhalten werden.
  */
 public class PGUtil {



More information about the Schmitzm-commits mailing list